@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt_extra.c,v 1.21 2002/05/17 20:53:18 nmav Exp $ */
+/* $Id: mcrypt_extra.c,v 1.23 2002/07/06 10:18:18 nmav Exp $ */
 
 #include <libdefs.h>
 #include <bzero.h>
@@ -62,7 +62,7 @@ WIN32DLL_DEFINE char *mcrypt_readdir(DIR * dirstream)
 
 extern const mcrypt_preloaded mps[];
 
-WIN32DLL_DEFINE char **mcrypt_list_algorithms(char *libdir, int *size)
+WIN32DLL_DEFINE char **mcrypt_list_algorithms(const char *libdir, int *size)
 {
 	DIR *pdir;
 	char directory[512];
@@ -170,7 +170,7 @@ WIN32DLL_DEFINE char **mcrypt_list_algorithms(char *libdir, int *size)
 		return NULL;
 }
 
-WIN32DLL_DEFINE char **mcrypt_list_modes(char *libdir, int *size)
+WIN32DLL_DEFINE char **mcrypt_list_modes(const char *libdir, int *size)
 {
 	DIR *pdir;
 	char directory[512];
