@@ -2275,11 +2275,11 @@ find_handle_callback (filename, data, ignored)
      lt_ptr data;
      lt_ptr ignored;
 {
-  lt_dlhandle  *handle		= (lt_dlhandle *) data;
-  int		notfound	= access (filename, R_OK);
+  lt_dlhandle  *handle	= (lt_dlhandle *) data;
+  int		found	= access (filename, R_OK);
 
   /* Bail out if file cannot be read...  */
-  if (notfound)
+  if (!found)
     return 0;
 
   /* Try to dlopen the file, but do not continue searching in any
@@ -2875,7 +2875,7 @@ try_dlopen (phandle, filename)
 #endif
 		   )))
 	{
-          if (tryall_dlopen (&newhandle, filename) != 0)
+	  if (tryall_dlopen (&newhandle, filename) != 0)
             {
               newhandle = NULL;
             }
